@@ -1,5 +1,11 @@
 use super::{Action, OpTrait};
-use crate::{items::TargetData, menu::PendingMenu, screen::NavMode, state::State, term::Term};
+use crate::{
+    items::TargetData,
+    menu::{arg::Arg, PendingMenu},
+    screen::NavMode,
+    state::{root_menu, State},
+    term::Term,
+};
 use derive_more::Display;
 use std::rc::Rc;
 
@@ -9,32 +15,34 @@ pub(crate) struct Quit;
 impl OpTrait for Quit {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
         Some(Rc::new(|state, term| {
-            match state.pending_menu {
-                None => {
-                    if state.screens.len() == 1 {
-                        let quit = Rc::new(|state: &mut State, _term: &mut Term| {
-                            state.quit = true;
-                            Ok(())
-                        });
+            let menu = state
+                .pending_menu
+                .as_ref()
+                .map(|pending_menu| pending_menu.menu);
 
-                        let mut action = if state.config.general.confirm_quit.enabled {
-                            super::create_y_n_prompt(quit, "Really quit?")
-                        } else {
-                            quit
-                        };
+            if menu == root_menu(&state.config) {
+                if state.screens.len() == 1 {
+                    let quit = Rc::new(|state: &mut State, _term: &mut Term| {
+                        state.quit = true;
+                        Ok(())
+                    });
 
-                        Rc::get_mut(&mut action).unwrap()(state, term)?;
+                    let mut action = if state.config.general.confirm_quit.enabled {
+                        super::create_y_n_prompt(quit, "Really quit?")
                     } else {
-                        state.screens.pop();
-                        if let Some(screen) = state.screens.last_mut() {
-                            screen.update()?;
-                        }
+                        quit
+                    };
+
+                    Rc::get_mut(&mut action).unwrap()(state, term)?;
+                } else {
+                    state.screens.pop();
+                    if let Some(screen) = state.screens.last_mut() {
+                        screen.update()?;
                     }
                 }
-                _ => {
-                    state.pending_menu = None;
-                    return Ok(());
-                }
+            } else {
+                state.pending_menu = root_menu(&state.config).map(PendingMenu::init);
+                return Ok(());
             }
 
             Ok(())
@@ -72,9 +80,7 @@ impl OpTrait for ToggleArg {
         let arg = self.0.clone();
         Some(Rc::new(move |state, _term| {
             if let Some(menu) = &mut state.pending_menu {
-                menu.args
-                    .entry(arg.clone().into())
-                    .and_modify(|value| *value = !*value);
+                menu.args.entry(arg.clone().into()).and_modify(Arg::toggle);
             }
             Ok(())
         }))
