@@ -1,11 +1,9 @@
 use super::{Action, OpTrait};
-use crate::{items::TargetData, state::State, term::Term};
+use crate::{items::TargetData, menu::arg::Arg, state::State, term::Term};
 use derive_more::Display;
 use std::{process::Command, rc::Rc};
 
-pub(crate) fn args() -> &'static [(&'static str, bool)] {
-    &[]
-}
+pub(crate) const ARGS: &[Arg] = &[Arg::new("--rebase", "Rebase local commits", false)];
 
 #[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
 #[display(fmt = "Pull")]
@@ -14,7 +12,8 @@ impl OpTrait for Pull {
     fn get_action(&self, _target: Option<&TargetData>) -> Option<Action> {
         Some(Rc::new(|state: &mut State, term: &mut Term| {
             let mut cmd = Command::new("git");
-            cmd.args(["pull"]);
+            cmd.arg("pull");
+            cmd.args(state.pending_menu.as_ref().unwrap().args());
 
             state.run_cmd_async(term, &[], cmd)?;
             Ok(())
