@@ -1,13 +1,11 @@
 use super::{Action, OpTrait};
-use crate::{items::TargetData, prompt::PromptData, state::State, term::Term, Res};
+use crate::{items::TargetData, menu::arg::Arg, prompt::PromptData, state::State, term::Term, Res};
 use derive_more::Display;
 use git2::{Repository, Status, StatusOptions};
 use std::{process::Command, rc::Rc};
 use tui_prompts::State as _;
 
-pub(crate) fn args() -> &'static [(&'static str, bool)] {
-    &[]
-}
+pub(crate) const ARGS: &[Arg] = &[];
 
 #[derive(Default, Clone, Copy, PartialEq, Eq, Debug, Display)]
 #[display(fmt = "Stash (include untracked)")]
@@ -54,7 +52,7 @@ impl OpTrait for StashWorktree {
 
                 if need_to_stash_index {
                     let mut cmd = Command::new("git");
-                    cmd.args(["stash", "pop", "1"]);
+                    cmd.args(["stash", "pop", "-q", "1"]);
                     state.run_cmd(term, &[], cmd)?;
                 }
             }
@@ -212,7 +210,7 @@ fn stash_target_action_prompt_update(
             };
 
             let mut cmd = Command::new("git");
-            cmd.args(["stash", command, stash_id.to_string().as_str()]);
+            cmd.args(["stash", command, "-q", stash_id.to_string().as_str()]);
 
             state.run_cmd(term, &[], cmd)?;
         }
