@@ -76,6 +76,7 @@ impl State {
         };
 
         let bindings = Bindings::from(&config.bindings);
+        let pending_menu = root_menu(&config).map(PendingMenu::init);
 
         Ok(Self {
             repo,
@@ -86,7 +87,7 @@ impl State {
             quit: false,
             screens,
             pending_cmd: None,
-            pending_menu: None,
+            pending_menu,
             current_cmd_log_entries: vec![],
             prompt: prompt::Prompt::new(),
         })
@@ -207,7 +208,7 @@ impl State {
         match op {
             Op::OpenMenu(_) => (),
             Op::ToggleArg(_) => (),
-            _ => self.pending_menu = None,
+            _ => self.pending_menu = root_menu(&self.config).map(PendingMenu::init),
         }
     }
 
@@ -285,9 +286,9 @@ impl State {
 
         let result = write_child_output_to_log(log_rwlock, child, status);
         self.pending_cmd = None;
+        self.screen_mut().update()?;
         result?;
 
-        self.screen_mut().update()?;
         Ok(true)
     }
 
@@ -337,6 +338,14 @@ impl State {
     }
 }
 
+pub(crate) fn root_menu(config: &Config) -> Option<Menu> {
+    if config.general.always_show_help.enabled {
+        Some(Menu::Help)
+    } else {
+        None
+    }
+}
+
 fn write_child_output_to_log(
     log_rwlock: &mut Arc<RwLock<CmdLogEntry>>,
     child: &mut Child,
@@ -350,17 +359,24 @@ fn write_child_output_to_log(
 
     drop(child.stdin.take());
 
-    let mut stderr = vec![];
+    let mut out_bytes = vec![];
     log::debug!("Reading stderr");
 
     child
         .stderr
         .take()
         .unwrap()
-        .read_to_end(&mut stderr)
+        .read_to_end(&mut out_bytes)
         .map_err(|e| format!("Couldn't read cmd output: {}", e))?;
 
-    let out_string = String::from_utf8(stderr.clone())?;
+    child
+        .stdout
+        .take()
+        .unwrap()
+        .read_to_end(&mut out_bytes)
+        .map_err(|e| format!("Couldn't read cmd output: {}", e))?;
+
+    let out_string = String::from_utf8(out_bytes.clone())?;
     *out_log = Some(out_string.into());
 
     if !status.success() {
