@@ -1,11 +1,14 @@
+use std::borrow::Cow;
 use std::sync::Arc;
 use std::sync::RwLock;
 
 use crate::bindings::Bindings;
 use crate::config::Config;
 use crate::items::Item;
+use crate::menu::arg::Arg;
 use crate::menu::PendingMenu;
 use crate::ops::Op;
+use crate::prompt::Prompt;
 use crate::state::State;
 use crate::CmdLogEntry;
 use itertools::EitherOrBoth;
@@ -32,12 +35,23 @@ pub(crate) fn ui(frame: &mut Frame, state: &mut State) {
             (0, None)
         };
 
-    let (menu_len, maybe_menu) = if let Some(ref menu) = state.pending_menu {
+    let State {
+        screens,
+        prompt:
+            Prompt {
+                data: maybe_prompt_data,
+                state: prompt_state,
+            },
+        pending_menu,
+        ..
+    } = state;
+
+    let (menu_len, maybe_menu) = if let Some(ref menu) = pending_menu {
         let (lines, table) = format_keybinds_menu(
             &state.config,
             &state.bindings,
             menu,
-            state.screen().get_selected_item(),
+            screens.last().unwrap().get_selected_item(),
         );
 
         (lines, Some(table))
@@ -45,42 +59,65 @@ pub(crate) fn ui(frame: &mut Frame, state: &mut State) {
         (0, None)
     };
 
+    // TODO Clean this up...
+
     let menu_top_padding = if menu_len > 0 { 1 } else { 0 };
-    let prompt_top_padding = if state.prompt.data.is_some() { 1 } else { 0 };
     let log_top_padding = if log_len > 0 { 1 } else { 0 };
 
-    let layout = Layout::new(
-        Direction::Vertical,
-        [
-            Constraint::Min(1),
-            Constraint::Length(menu_top_padding),
-            Constraint::Length(menu_len as u16),
-            Constraint::Length(prompt_top_padding),
-            Constraint::Length(if state.prompt.data.is_some() { 1 } else { 0 }),
-            Constraint::Length(log_top_padding),
-            Constraint::Length(log_len as u16),
-        ],
-    )
-    .split(frame.size());
+    if let Some(prompt_data) = maybe_prompt_data {
+        let layout = Layout::new(
+            Direction::Vertical,
+            [
+                Constraint::Min(1),
+                Constraint::Length(1),
+                Constraint::Length(1),
+                Constraint::Length(log_top_padding),
+                Constraint::Length(log_len as u16),
+            ],
+        )
+        .split(frame.size());
 
-    frame.render_widget(state.screen(), layout[0]);
+        frame.render_widget(screens.last().unwrap(), layout[0]);
 
-    if let Some(menu) = maybe_menu {
         frame.render_widget(popup_block(), layout[1]);
-        frame.render_widget(menu, layout[2]);
-    }
-
-    if let Some(prompt_data) = &state.prompt.data {
-        frame.render_widget(popup_block(), layout[3]);
         let prompt = TextPrompt::new(prompt_data.prompt_text.clone());
-        frame.render_stateful_widget(prompt, layout[4], &mut state.prompt.state);
+        frame.render_stateful_widget(prompt, layout[2], prompt_state);
+
+        if let Some(log) = maybe_log {
+            frame.render_widget(popup_block(), layout[3]);
+            frame.render_widget(log, layout[4]);
+        }
+
         let (cx, cy) = state.prompt.state.cursor();
         frame.set_cursor(cx, cy);
-    }
 
-    if let Some(log) = maybe_log {
-        frame.render_widget(popup_block(), layout[5]);
-        frame.render_widget(log, layout[6]);
+        screens.last_mut().unwrap().size = layout[0];
+    } else {
+        let layout = Layout::new(
+            Direction::Vertical,
+            [
+                Constraint::Min(1),
+                Constraint::Length(menu_top_padding),
+                Constraint::Length(menu_len as u16),
+                Constraint::Length(log_top_padding),
+                Constraint::Length(log_len as u16),
+            ],
+        )
+        .split(frame.size());
+
+        frame.render_widget(screens.last().unwrap(), layout[0]);
+
+        if let Some(menu) = maybe_menu {
+            frame.render_widget(popup_block(), layout[1]);
+            frame.render_widget(menu, layout[2]);
+        }
+
+        if let Some(log) = maybe_log {
+            frame.render_widget(popup_block(), layout[3]);
+            frame.render_widget(log, layout[4]);
+        }
+
+        screens.last_mut().unwrap().size = layout[0];
     }
 }
 
@@ -199,18 +236,26 @@ fn format_keybinds_menu<'b>(
             unreachable!();
         };
 
-        let on = *pending.args.get(name.as_str()).unwrap_or(&false);
+        let on = pending
+            .args
+            .get(name.as_str())
+            .map(Arg::is_acive)
+            .unwrap_or(false);
 
         right_column.push(Line::from(vec![
             Span::styled(&bind.raw, &style.hotkey),
+            Span::raw(" "),
+            Span::raw(pending.args.get(&Cow::from(name)).unwrap().display),
+            Span::raw(" ("),
             Span::styled(
-                format!(
-                    " {} ({})",
-                    bind.op.clone().implementation(),
-                    if on { "on" } else { "off" }
-                ),
-                if on { Style::new() } else { Style::new().dim() },
+                format!("{}", bind.op.clone().implementation()),
+                if on {
+                    Style::from(&style.active_arg)
+                } else {
+                    Style::new()
+                },
             ),
+            Span::raw(")"),
         ]));
     }
 
